@@ -79,11 +79,14 @@ class DummyProcess(threading.Thread):
 
 
 class Condition(threading._Condition):
-    notify_all = threading._Condition.notify_all.im_func
+    if sys.version_info[0] == 3:
+        notify_all = threading._Condition.notifyAll
+    else:
+        notify_all = threading._Condition.notifyAll.im_func
 
 
 Process = DummyProcess
-current_process = threading.current_thread
+current_process = threading.currentThread
 current_process()._children = weakref.WeakKeyDictionary()
 
 
