@@ -469,6 +469,10 @@ def main():
     preparation_data = load(from_parent)
     prepare(preparation_data)
     # Huge hack to make logging before Process.run work.
+    try:
+        os.environ["MP_MAIN_FILE"] = sys.modules["__main__"].__file__
+    except KeyError:
+        pass
     loglevel = os.environ.get("_MP_FORK_LOGLEVEL_")
     logfile = os.environ.get("_MP_FORK_LOGFILE_") or None
     format = os.environ.get("_MP_FORK_LOGFORMAT_")
